---
title: Python API reference
---

This package is primarily a CLI. The core modules are documented below for advanced users.

## Config

::: cc_liquid.config.Config

## Data loading

::: cc_liquid.data_loader.DataLoader

## Trading logic

::: cc_liquid.trader.CCLiquid

### Callback protocols

::: cc_liquid.callbacks.CCLiquidCallbacks


